@@ -20,6 +20,7 @@
     License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#define _POSIX_C_SOURCE 200112L /* unsetenv */
 #include "pulsesupport.h"
 
 #include <QAbstractEventDispatcher>
@@ -437,11 +438,12 @@ static void ext_device_manager_read_cb(pa_context *c, const pa_ext_device_manage
         // our device info and can exit and reconnect
         if (s_context != c)
             pa_context_disconnect(c);
+
+        return; // eol
     }
 
-    if (!info)
-        return;
-
+    // If we aren't at eol we expect info to be valid!
+    Q_ASSERT(info);
     Q_ASSERT(info->name);
     Q_ASSERT(info->description);
     Q_ASSERT(info->icon);
